window.Gleam.initSearch([{"doc":"franz","title":"franz","content":"# franz\n\n[![Package Version](https://img.shields.io/hexpm/v/franz)](https://hex.pm/packages/franz)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/franz/)\n\n`franz` is a Gleam library for interacting with Kafka. It provides functionalities to produce and consume messages, handle topics, and manage configurations.\n\n## Installation\n\nAdd `franz` to your Gleam project:\n\n```sh\ngleam add franz\n```\n\n## Usage\n\n```gleam\n  import franz\n  import franz/consumer_config\n  import franz/group_config\n  import franz/group_subscriber\n  import franz/message_type\n  import franz/partitions\n  import franz/producer\n  import franz/topic_subscriber\n  import gleam/io\n\n  pub fn main() {\n    let topic = &quot;gleamy_topic&quot;\n    let endpoint = #(&quot;localhost&quot;, 9092)\n    let assert Ok(connection) =\n      franz.new_client([endpoint])\n      |&gt; franz.with_config(franz.AutoStartProducers(True))\n      |&gt; franz.start()\n\n    //let assert Ok(Nil) = franz.create_topic([endpoint], topic, 1, 1)\n\n    let assert Ok(Nil) =\n      producer.produce_sync(\n        connection,\n        topic,\n        producer.Partitioner(producer.Random),\n        &lt;&lt;&quot;gracias&quot;&gt;&gt;,\n        producer.Value(&lt;&lt;&quot;bitte&quot;&gt;&gt;, [#(&quot;meta&quot;, &quot;data&quot;)]),\n      )\n\n    let counter = 0\n    let assert Ok(_pid) =\n      group_subscriber.new(\n        connection,\n        &quot;group&quot;,\n        [topic],\n        message_type.Message,\n        fn(message, counter) {\n          io.debug(message)\n          io.debug(counter)\n          group_subscriber.commit(counter + 1)\n        },\n        counter,\n      )\n      |&gt; group_subscriber.with_group_config(\n        group_config.OffsetCommitIntervalSeconds(10),\n      )\n      |&gt; group_subscriber.with_consumer_config(consumer_config.BeginOffset(\n        consumer_config.Earliest,\n      ))\n      |&gt; group_subscriber.start()\n\n    let assert Ok(_pid) =\n      topic_subscriber.new(\n        connection,\n        topic,\n        partitions.All,\n        message_type.Message,\n        fn(_, message, state) {\n          io.debug(message)\n          topic_subscriber.ack(state)\n        },\n        Nil,\n      )\n      |&gt; topic_subscriber.with_config(consumer_config.BeginOffset(\n        consumer_config.Earliest,\n      ))\n      |&gt; topic_subscriber.start()\n  }\n```\n","url":"index.html"},{"doc":"franz/isolation_level","title":"IsolationLevel","content":"pub type IsolationLevel {\n  ReadCommitted\n  ReadUncommitted\n}\n\nReadCommitted\n\n\nReadUncommitted\n\n\nSynonyms:\nfranz/isolation_level.IsolationLevel\nfranz/isolation_level IsolationLevel","url":"franz/isolation_level.html#IsolationLevel"},{"doc":"franz/isolation_level","title":"franz/isolation_level","content":"","url":"franz/isolation_level.html"},{"doc":"franz/producer_config","title":"Compression","content":"pub type Compression {\n  NoCompression\n  Gzip\n  Snappy\n}\n\nNoCompression\n Default value\n\nGzip\n Gzip compression\n\nSnappy\n Snappy compression\n\nSynonyms:\nfranz/producer_config.Compression\nfranz/producer_config Compression","url":"franz/producer_config.html#Compression"},{"doc":"franz/producer_config","title":"ProducerConfig","content":"pub type ProducerConfig {\n  RequiredAcks(Int)\n  AckTimeout(Int)\n  PartitionBufferLimit(Int)\n  PartitionOnwireLimit(Int)\n  MaxBatchSize(Int)\n  MaxRetries(Int)\n  RetryBackoffMs(Int)\n  Compression(Compression)\n  MaxLingerMs(Int)\n  MaxLingerCount(Int)\n}\n\nRequiredAcks(Int)\n How many acknowledgements the kafka broker should receive from the clustered replicas before acking producer.\n  0: the broker will not send any response (this is the only case where the broker will not reply to a request) \n  1: The leader will wait the data is written to the local log before sending a response. \n -1: If it is -1 the broker will block until the message is committed by all in sync replicas before acking.\n Default: -1.\n\nAckTimeout(Int)\n Maximum time in milliseconds the broker can await the receipt of the number of acknowledgements in RequiredAcks. The timeout is not an exact limit on the request time for a few reasons: \n (1) it does not include network latency, \n (2) the timer begins at the beginning of the processing of this request so if many requests are queued due to broker overload that wait time will not be included,\n (3) kafka leader will not terminate a local write so if the local write time exceeds this timeout it will not be respected.\n Default: 10000 ms.\n\nPartitionBufferLimit(Int)\n How many requests (per-partition) can be buffered without blocking the caller.\n The callers are released (by receiving the &#39;brod_produce_req_buffered&#39; reply) once the request is taken into buffer and after the request has been put on wire, then the caller may expect a reply &#39;brod_produce_req_acked&#39; when the request is accepted by kafka.\n Default: 256.\n\nPartitionOnwireLimit(Int)\n How many message sets (per-partition) can be sent to kafka broker asynchronously before receiving ACKs from broker.\n NOTE: setting a number greater than 1 may cause messages being persisted in an order different from the order they were produced.\n Default: 1.\n\nMaxBatchSize(Int)\n In case callers are producing faster than brokers can handle (or congestion on wire), try to accumulate small requests into batches as much as possible but not exceeding max_batch_size.\n OBS: If compression is enabled, care should be taken when picking the max batch size, because a compressed batch will be produced as one message and this message might be larger than &#39;max.message.bytes&#39; in kafka config (or topic config)\n Default: 1M.\n\nMaxRetries(Int)\n If MaxRetries(Int) is given, the producer retry produce request for N times before crashing in case of failures like connection being shutdown by remote or exceptions received in produce response from kafka.\n The special value N = -1 means &quot;retry indefinitely&quot;\n Default: 3.\n\nRetryBackoffMs(Int)\n Time in milli-seconds to sleep before retry the failed produce request.\n Default: 500 ms.\n\nCompression(Compression)\n Use this option to enable compression of messages.\n Default: NoCompression.\n\nMaxLingerMs(Int)\n Messages are allowed to &#39;linger&#39; in buffer for this amount of milli-seconds before being sent. Definition of &#39;linger&#39;: A message is in &quot;linger&quot; state when it is allowed to be sent on-wire, but chosen not to (for better batching).\n The default value is 0 for 2 reasons:\n   1. Backward compatibility (for 2.x releases)\n   2. Not to surprise consumer.produce_sync() callers\n Default: 0 ms.\n\nMaxLingerCount(Int)\n At most this amount (count not size) of messages are allowed to &quot;linger&quot; in buffer. Messages will be sent regardless of &quot;linger&quot; age when this threshold is hit.\n NOTE: It does not make sense to have this value set larger than PartitionBufferLimit(Int)\n Default: 0.\n\nSynonyms:\nfranz/producer_config.ProducerConfig\nfranz/producer_config ProducerConfig","url":"franz/producer_config.html#ProducerConfig"},{"doc":"franz/producer_config","title":"franz/producer_config","content":"","url":"franz/producer_config.html"},{"doc":"franz","title":"ClientBuilder","content":"pub opaque type ClientBuilder\n\n\nSynonyms:\nfranz.ClientBuilder\nfranz ClientBuilder","url":"franz.html#ClientBuilder"},{"doc":"franz","title":"ClientConfig","content":"pub type ClientConfig {\n  RestartDelaySeconds(Int)\n  ReconnectCoolDownSeconds(Int)\n  AllowTopicAutoCreation(Bool)\n  AutoStartProducers(Bool)\n  DefaultProducerConfig(List(producer_config.ProducerConfig))\n  UnknownTopicCacheTtl(Int)\n}\n\nRestartDelaySeconds(Int)\n How long to wait between attempts to restart brod_client process when it crashes.\n Default: 10 seconds\n\nReconnectCoolDownSeconds(Int)\n Delay this configured number of seconds before retrying to establish a new connection to the kafka partition leader.\n Default: 1 second\n\nAllowTopicAutoCreation(Bool)\n By default, brod respects what is configured in the broker about topic auto-creation. i.e. whether auto.create.topics.enable is set in the broker configuration.\n However if allow_topic_auto_creation is set to false in client config, brod will avoid sending metadata requests that may cause an auto-creation of the topic regardless of what broker config is.\n Default: true\n\nAutoStartProducers(Bool)\n If true, brod client will spawn a producer automatically when user is trying to call produce but did not call brod:start_producer explicitly. \n Can be useful for applications which don&#39;t know beforehand which topics they will be working with.\n Default: false\n\nDefaultProducerConfig(List(producer_config.ProducerConfig))\n Producer configuration to use when auto_start_producers is true.\n Default: []\n\nUnknownTopicCacheTtl(Int)\n For how long unknown_topic error will be cached, in ms.\n Default: 120000\n\nSynonyms:\nfranz.ClientConfig\nfranz ClientConfig","url":"franz.html#ClientConfig"},{"doc":"franz","title":"FetchOption","content":"pub type FetchOption {\n  MaxWaitTime(Int)\n  MinBytes(Int)\n  MaxBytes(Int)\n  IsolationLevel(isolation_level.IsolationLevel)\n}\n\nMaxWaitTime(Int)\n The maximum time (in millis) to block wait until there are enough messages that have in sum at least min_bytes bytes.\n The waiting will end as soon as either min_bytes is satisfied or max_wait_time is exceeded, whichever comes first.\n Defaults to 1 second.\n\nMinBytes(Int)\n The minimum size of the message set. If it there are not enough messages, Kafka will block wait (but at most for max_wait_time).\n This implies that the response may be actually smaller in case the time runs out. If you set it to 0, Kafka will respond immediately (possibly with an empty message set).\n You can use this option together with max_wait_time to configure throughput, latency, and size of message sets. \n Defaults to 0.\n\nMaxBytes(Int)\n The maximum size of the message set. \n Note that this is not an absolute maximum, if the first message in the message set is larger than this value, the message will still be returned to ensure that progress can be made.\n Defaults to 1 MB.\n\nIsolationLevel(isolation_level.IsolationLevel)\n This setting controls the visibility of transactional records.\n Using read_uncommitted makes all records visible. With read_committed, non-transactional and committed transactional records are visible.\n To be more concrete, read_committed returns all data from offsets smaller than the current LSO (last stable offset), and enables the inclusion of the list of aborted transactions in the result, which allows consumers to discard aborted transactional records.\n Defaults to read_committed.\n\nSynonyms:\nfranz.FetchOption\nfranz FetchOption","url":"franz.html#FetchOption"},{"doc":"franz","title":"FranzClient","content":"pub type FranzClient\n\n\nSynonyms:\nfranz.FranzClient\nfranz FranzClient","url":"franz.html#FranzClient"},{"doc":"franz","title":"FranzError","content":"pub type FranzError {\n  UnknownError\n  ClientDown\n  UnknownTopicOrPartition\n  ProducerDown\n  TopicAlreadyExists\n  ConsumerNotFound(String)\n  ProducerNotFound(String, Int)\n  OffsetOutOfRange\n}\n\nUnknownError\n\n\nClientDown\n\n\nUnknownTopicOrPartition\n\n\nProducerDown\n\n\nTopicAlreadyExists\n\n\nConsumerNotFound(String)\n\n\nProducerNotFound(String, Int)\n\n\nOffsetOutOfRange\n\n\nSynonyms:\nfranz.FranzError\nfranz FranzError","url":"franz.html#FranzError"},{"doc":"franz","title":"KafkaMessage","content":"pub type KafkaMessage {\n  KafkaMessage(\n    offset: Int,\n    key: BitArray,\n    value: BitArray,\n    timestamp_type: TimeStampType,\n    timestamp: Int,\n    headers: List(#(String, String)),\n  )\n  KafkaMessageSet(\n    topic: String,\n    partition: Int,\n    high_wm_offset: Int,\n    messages: List(KafkaMessage),\n  )\n}\n\nKafkaMessage(\n  offset: Int,\n  key: BitArray,\n  value: BitArray,\n  timestamp_type: TimeStampType,\n  timestamp: Int,\n  headers: List(#(String, String)),\n)\n\n\nKafkaMessageSet(\n  topic: String,\n  partition: Int,\n  high_wm_offset: Int,\n  messages: List(KafkaMessage),\n)\n\n\nSynonyms:\nfranz.KafkaMessage\nfranz KafkaMessage","url":"franz.html#KafkaMessage"},{"doc":"franz","title":"TimeStampType","content":"pub type TimeStampType {\n  Undefined\n  Create\n  Append\n}\n\nUndefined\n\n\nCreate\n\n\nAppend\n\n\nSynonyms:\nfranz.TimeStampType\nfranz TimeStampType","url":"franz.html#TimeStampType"},{"doc":"franz","title":"create_topic","content":"pub fn create_topic(\n  bootstrap_endpoints: List(#(String, Int)),\n  topic: String,\n  partitions: Int,\n  replication_factor: Int,\n) -&gt; Result(Nil, FranzError)\n Create a new topic with the given number of partitions and replication factor.\nSynonyms:\nfranz.create_topic\nfranz create_topic","url":"franz.html#create_topic"},{"doc":"franz","title":"fetch","content":"pub fn fetch(\n  client: FranzClient,\n  topic: String,\n  partition: Int,\n  offset: Int,\n  fetch_options: List(FetchOption),\n) -&gt; Result(#(Int, KafkaMessage), FranzError)\n Fetch a single message set from the given topic-partition.\n On success, the function returns the messages along with the last stable offset (when using ReadCommited mode, the last committed offset) or the high watermark offset (offset of the last message that was successfully copied to all replicas, incremented by 1), whichever is lower. \n In essence, this is the offset up to which it was possible to read the messages at the time of fetching\nSynonyms:\nfranz.fetch\nfranz fetch","url":"franz.html#fetch"},{"doc":"franz","title":"new_client","content":"pub fn new_client(\n  bootstrap_endpoints: List(#(String, Int)),\n) -&gt; ClientBuilder\n Create a new client builder with the given bootstrap endpoints.\nSynonyms:\nfranz.new_client\nfranz new_client","url":"franz.html#new_client"},{"doc":"franz","title":"start","content":"pub fn start(\n  client_builder: ClientBuilder,\n) -&gt; Result(FranzClient, FranzError)\n Start a new client with the given configuration.\nSynonyms:\nfranz.start\nfranz start","url":"franz.html#start"},{"doc":"franz","title":"stop_client","content":"pub fn stop_client(client: FranzClient) -&gt; Nil\n Stops a client.\nSynonyms:\nfranz.stop_client\nfranz stop_client","url":"franz.html#stop_client"},{"doc":"franz","title":"with_config","content":"pub fn with_config(\n  client_builder: ClientBuilder,\n  client_config: ClientConfig,\n) -&gt; ClientBuilder\n Add a client configuration to the client builder.\nSynonyms:\nfranz.with_config\nfranz with_config","url":"franz.html#with_config"},{"doc":"franz","title":"franz","content":"","url":"franz.html"},{"doc":"franz/consumer_config","title":"ConsumerConfig","content":"pub type ConsumerConfig {\n  BeginOffset(OffsetTime)\n  MinBytes(Int)\n  MaxBytes(Int)\n  MaxWaitTime(Int)\n  SleepTimeout(Int)\n  PrefetchCount(Int)\n  PrefetchBytes(Int)\n  OffsetResetPolicy(OffsetResetPolicy)\n  SizeStatWindow(Int)\n  IsolationLevel(isolation_level.IsolationLevel)\n  ShareLeaderConn(Bool)\n}\n\nBeginOffset(OffsetTime)\n The offset from which to begin fetch requests. A subscriber may consume and process messages, then persist the associated offset to a persistent storage, then start (or restart) from last_processed_offset + 1 as the begin_offset to proceed. The offset has to already exist at the time of calling.\n Default: Latest\n\nMinBytes(Int)\n Minimal bytes to fetch in a batch of messages\n Default: 0\n\nMaxBytes(Int)\n Maximum bytes to fetch in a batch of messages.\n NOTE: this value might be expanded to retry when it is not enough to fetch even a single message, then slowly shrunk back to the given value.\n Default: 1 MB\n\nMaxWaitTime(Int)\n Max number of seconds allowed for the broker to collect min_bytes of messages in fetch response.\n Default: 10000 ms\n\nSleepTimeout(Int)\n Allow consumer process to sleep this amount of ms if kafka replied &#39;empty&#39; message set.\n Default: 1000 ms\n\nPrefetchCount(Int)\n The window size (number of messages) allowed to fetch-ahead.\n Default: 10\n\nPrefetchBytes(Int)\n The total number of bytes allowed to fetch-ahead. \n Default: 100KB\n\nOffsetResetPolicy(OffsetResetPolicy)\n How to reset BeginOffset if OffsetOutOfRange exception is received.\n Default: ResetBySubscriber\n\nSizeStatWindow(Int)\n The moving-average window size to calculate average message size. Average message size is used to shrink max_bytes in fetch requests after it has been expanded to fetch a large message. Use 0 to immediately shrink back to original max_bytes from config. A size estimation allows users to set a relatively small max_bytes, then let it dynamically adjust to a number around PrefetchCount * AverageSize.\n Default: 5\n\nIsolationLevel(isolation_level.IsolationLevel)\n Level to control what transaction records are exposed to the consumer.\n Two values are allowed, read_uncommitted to retrieve all records, independently on the transaction outcome (if any), and read_committed to get only the records from committed transactions\n Default: ReadCommited\n\nShareLeaderConn(Bool)\n Whether or not share the partition leader connection with other producers or consumers. Set to true to consume less TCP connections towards Kafka, but may lead to higher fetch latency. This is because Kafka can ony accumulate messages for the oldest fetch request, later requests behind it may get blocked until max_wait_time expires for the oldest one.\n\nSynonyms:\nfranz/consumer_config.ConsumerConfig\nfranz/consumer_config ConsumerConfig","url":"franz/consumer_config.html#ConsumerConfig"},{"doc":"franz/consumer_config","title":"OffsetResetPolicy","content":"pub type OffsetResetPolicy {\n  ResetBySubscriber\n  ResetToEarliest\n  ResetToLatest\n}\n\nResetBySubscriber\n Default value\n\nResetToEarliest\n\n\nResetToLatest\n\n\nSynonyms:\nfranz/consumer_config.OffsetResetPolicy\nfranz/consumer_config OffsetResetPolicy","url":"franz/consumer_config.html#OffsetResetPolicy"},{"doc":"franz/consumer_config","title":"OffsetTime","content":"pub type OffsetTime {\n  Latest\n  Earliest\n  MessageTimestamp(Int)\n}\n\nLatest\n Default value\n\nEarliest\n\n\nMessageTimestamp(Int)\n\n\nSynonyms:\nfranz/consumer_config.OffsetTime\nfranz/consumer_config OffsetTime","url":"franz/consumer_config.html#OffsetTime"},{"doc":"franz/consumer_config","title":"franz/consumer_config","content":"","url":"franz/consumer_config.html"},{"doc":"franz/group_config","title":"GroupConfig","content":"pub type GroupConfig {\n  SessionTimeoutSeconds(Int)\n  RebalanceTimeoutSeconds(Int)\n  HeartbeatRateSeconds(Int)\n  MaxRejoinAttempts(Int)\n  RejoinDelaySeconds(Int)\n  OffsetCommitIntervalSeconds(Int)\n  OffsetRetentionSeconds(Int)\n}\n\nSessionTimeoutSeconds(Int)\n\n\nRebalanceTimeoutSeconds(Int)\n\n\nHeartbeatRateSeconds(Int)\n\n\nMaxRejoinAttempts(Int)\n\n\nRejoinDelaySeconds(Int)\n\n\nOffsetCommitIntervalSeconds(Int)\n\n\nOffsetRetentionSeconds(Int)\n\n\nSynonyms:\nfranz/group_config.GroupConfig\nfranz/group_config GroupConfig","url":"franz/group_config.html#GroupConfig"},{"doc":"franz/group_config","title":"franz/group_config","content":"","url":"franz/group_config.html"},{"doc":"franz/message_type","title":"MessageType","content":"pub type MessageType {\n  Message\n  MessageSet\n}\n\nMessage\n\n\nMessageSet\n\n\nSynonyms:\nfranz/message_type.MessageType\nfranz/message_type MessageType","url":"franz/message_type.html#MessageType"},{"doc":"franz/message_type","title":"franz/message_type","content":"","url":"franz/message_type.html"},{"doc":"franz/group_subscriber","title":"CallbackReturn","content":"pub type CallbackReturn\n\n\nSynonyms:\nfranz/group_subscriber.CallbackReturn\nfranz/group_subscriber CallbackReturn","url":"franz/group_subscriber.html#CallbackReturn"},{"doc":"franz/group_subscriber","title":"GroupBuilder","content":"pub opaque type GroupBuilder(callback_init_state)\n\n\nSynonyms:\nfranz/group_subscriber.GroupBuilder\nfranz/group_subscriber GroupBuilder","url":"franz/group_subscriber.html#GroupBuilder"},{"doc":"franz/group_subscriber","title":"ack","content":"pub fn ack(cb_state: a) -&gt; CallbackReturn\n Acknowledge the processing of the message.\nSynonyms:\nfranz/group_subscriber.ack\nfranz/group_subscriber ack","url":"franz/group_subscriber.html#ack"},{"doc":"franz/group_subscriber","title":"commit","content":"pub fn commit(cb_state: a) -&gt; CallbackReturn\n Commit the offset of the last message that was successfully processed.\nSynonyms:\nfranz/group_subscriber.commit\nfranz/group_subscriber commit","url":"franz/group_subscriber.html#commit"},{"doc":"franz/group_subscriber","title":"new","content":"pub fn new(\n  client: FranzClient,\n  group_id: String,\n  topics: List(String),\n  message_type: MessageType,\n  callback: fn(KafkaMessage, a) -&gt; CallbackReturn,\n  init_callback_state: a,\n) -&gt; GroupBuilder(a)\n Create a new group subscriber builder.\nSynonyms:\nfranz/group_subscriber.new\nfranz/group_subscriber new","url":"franz/group_subscriber.html#new"},{"doc":"franz/group_subscriber","title":"start","content":"pub fn start(\n  group_builder: GroupBuilder(a),\n) -&gt; Result(Pid, FranzError)\n Start a new group subscriber.\nSynonyms:\nfranz/group_subscriber.start\nfranz/group_subscriber start","url":"franz/group_subscriber.html#start"},{"doc":"franz/group_subscriber","title":"stop","content":"pub fn stop(pid: Pid) -&gt; Result(Nil, FranzError)\n\nSynonyms:\nfranz/group_subscriber.stop\nfranz/group_subscriber stop","url":"franz/group_subscriber.html#stop"},{"doc":"franz/group_subscriber","title":"with_consumer_config","content":"pub fn with_consumer_config(\n  group_builder: GroupBuilder(a),\n  consumer_config: ConsumerConfig,\n) -&gt; GroupBuilder(a)\n Add a consumer configuration to the group builder.\nSynonyms:\nfranz/group_subscriber.with_consumer_config\nfranz/group_subscriber with_consumer_config","url":"franz/group_subscriber.html#with_consumer_config"},{"doc":"franz/group_subscriber","title":"with_group_config","content":"pub fn with_group_config(\n  group_builder: GroupBuilder(a),\n  group_config: GroupConfig,\n) -&gt; GroupBuilder(a)\n Add a group configuration to the group builder.\nSynonyms:\nfranz/group_subscriber.with_group_config\nfranz/group_subscriber with_group_config","url":"franz/group_subscriber.html#with_group_config"},{"doc":"franz/group_subscriber","title":"franz/group_subscriber","content":"","url":"franz/group_subscriber.html"},{"doc":"franz/partitions","title":"Partitions","content":"pub type Partitions {\n  Partititons(List(Int))\n  All\n}\n\nPartititons(List(Int))\n\n\nAll\n\n\nSynonyms:\nfranz/partitions.Partitions\nfranz/partitions Partitions","url":"franz/partitions.html#Partitions"},{"doc":"franz/partitions","title":"franz/partitions","content":"","url":"franz/partitions.html"},{"doc":"franz/producer","title":"Partitioner","content":"pub type Partitioner {\n  PartitionFun(\n    fn(String, Int, BitArray, BitArray) -&gt; Result(Int, Nil),\n  )\n  Random\n  Hash\n}\n\nPartitionFun(\n  fn(String, Int, BitArray, BitArray) -&gt; Result(Int, Nil),\n)\n Partititoner function with Topic, PartitionCount, Key and Value that should return a partition number.\n\nRandom\n Random partitioner.\n\nHash\n Hash partititoner\n\nSynonyms:\nfranz/producer.Partitioner\nfranz/producer Partitioner","url":"franz/producer.html#Partitioner"},{"doc":"franz/producer","title":"ProducerBuilder","content":"pub opaque type ProducerBuilder\n\n\nSynonyms:\nfranz/producer.ProducerBuilder\nfranz/producer ProducerBuilder","url":"franz/producer.html#ProducerBuilder"},{"doc":"franz/producer","title":"ProducerPartition","content":"pub type ProducerPartition {\n  Partition(Int)\n  Partitioner(Partitioner)\n}\n\nPartition(Int)\n\n\nPartitioner(Partitioner)\n\n\nSynonyms:\nfranz/producer.ProducerPartition\nfranz/producer ProducerPartition","url":"franz/producer.html#ProducerPartition"},{"doc":"franz/producer","title":"Value","content":"pub type Value {\n  Value(value: BitArray, headers: List(#(String, String)))\n  ValueWithTimestamp(\n    value: BitArray,\n    timestamp: Int,\n    headers: List(#(String, String)),\n  )\n}\n\nValue(value: BitArray, headers: List(#(String, String)))\n\n\nValueWithTimestamp(\n  value: BitArray,\n  timestamp: Int,\n  headers: List(#(String, String)),\n)\n\n\nSynonyms:\nfranz/producer.Value\nfranz/producer Value","url":"franz/producer.html#Value"},{"doc":"franz/producer","title":"new","content":"pub fn new(client: FranzClient, topic: String) -&gt; ProducerBuilder\n Creates a new producer builder with the given Franz client and topic.\nSynonyms:\nfranz/producer.new\nfranz/producer new","url":"franz/producer.html#new"},{"doc":"franz/producer","title":"produce","content":"pub fn produce(\n  client: FranzClient,\n  topic: String,\n  partition: ProducerPartition,\n  key: BitArray,\n  value: Value,\n) -&gt; Result(Nil, FranzError)\n Produce one or more messages.\n A producer for the particular topic has to be already started (by calling producer.start()), unless you have specified AutoStartProducers(True) when starting the client.\nSynonyms:\nfranz/producer.produce\nfranz/producer produce","url":"franz/producer.html#produce"},{"doc":"franz/producer","title":"produce_cb","content":"pub fn produce_cb(\n  client: FranzClient,\n  topic: String,\n  partition: ProducerPartition,\n  key: BitArray,\n  value: Value,\n  callback: fn(Int, Int) -&gt; a,\n) -&gt; Result(Int, FranzError)\n This function will await the kafka ack before returning and calling the callback.\n A producer for the particular topic has to be already started (by calling producer.start()), unless you have specified AutoStartProducers(True) when starting the client.\n Returns the partititon of the produced message.\nSynonyms:\nfranz/producer.produce_cb\nfranz/producer produce_cb","url":"franz/producer.html#produce_cb"},{"doc":"franz/producer","title":"produce_sync","content":"pub fn produce_sync(\n  client: FranzClient,\n  topic: String,\n  partition: ProducerPartition,\n  key: BitArray,\n  value: Value,\n) -&gt; Result(Nil, FranzError)\n This function will await the kafka ack before returning.\n A producer for the particular topic has to be already started (by calling producer.start()), unless you have specified AutoStartProducers(True) when starting the client.\nSynonyms:\nfranz/producer.produce_sync\nfranz/producer produce_sync","url":"franz/producer.html#produce_sync"},{"doc":"franz/producer","title":"produce_sync_offset","content":"pub fn produce_sync_offset(\n  client: FranzClient,\n  topic: String,\n  partition: ProducerPartition,\n  key: BitArray,\n  value: Value,\n) -&gt; Result(Int, FranzError)\n This function will await the kafka ack before returning.\n A producer for the particular topic has to be already started (by calling producer.start()), unless you have specified AutoStartProducers(True) when starting the client.\n This function will return the offset of the produced message.\nSynonyms:\nfranz/producer.produce_sync_offset\nfranz/producer produce_sync_offset","url":"franz/producer.html#produce_sync_offset"},{"doc":"franz/producer","title":"start","content":"pub fn start(builder: ProducerBuilder) -&gt; Result(Nil, FranzError)\n Start a producer with the given configuration.\n A producer for the particular topic has to be already started (by calling producer.start()), unless you have specified AutoStartProducers(True) when starting the client.\nSynonyms:\nfranz/producer.start\nfranz/producer start","url":"franz/producer.html#start"},{"doc":"franz/producer","title":"with_config","content":"pub fn with_config(\n  builder: ProducerBuilder,\n  config: ProducerConfig,\n) -&gt; ProducerBuilder\n Add a producer configuration to the producer builder.\nSynonyms:\nfranz/producer.with_config\nfranz/producer with_config","url":"franz/producer.html#with_config"},{"doc":"franz/producer","title":"franz/producer","content":"","url":"franz/producer.html"},{"doc":"franz/topic_subscriber","title":"Ack","content":"pub type Ack\n\n\nSynonyms:\nfranz/topic_subscriber.Ack\nfranz/topic_subscriber Ack","url":"franz/topic_subscriber.html#Ack"},{"doc":"franz/topic_subscriber","title":"Builder","content":"pub opaque type Builder(callback_init_state)\n\n\nSynonyms:\nfranz/topic_subscriber.Builder\nfranz/topic_subscriber Builder","url":"franz/topic_subscriber.html#Builder"},{"doc":"franz/topic_subscriber","title":"ack","content":"pub fn ack(cb_state: a) -&gt; Ack\n Acknowledge the processing of the message.\nSynonyms:\nfranz/topic_subscriber.ack\nfranz/topic_subscriber ack","url":"franz/topic_subscriber.html#ack"},{"doc":"franz/topic_subscriber","title":"new","content":"pub fn new(\n  client: FranzClient,\n  topic: String,\n  partitions: Partitions,\n  message_type: MessageType,\n  callback: fn(Int, KafkaMessage, a) -&gt; Ack,\n  init_callback_state: a,\n) -&gt; Builder(a)\n Create a new topic subscriber builder.\nSynonyms:\nfranz/topic_subscriber.new\nfranz/topic_subscriber new","url":"franz/topic_subscriber.html#new"},{"doc":"franz/topic_subscriber","title":"start","content":"pub fn start(builder: Builder(a)) -&gt; Result(Pid, FranzError)\n Start a new topic subscriber.\nSynonyms:\nfranz/topic_subscriber.start\nfranz/topic_subscriber start","url":"franz/topic_subscriber.html#start"},{"doc":"franz/topic_subscriber","title":"with_commited_offset","content":"pub fn with_commited_offset(\n  builder: Builder(a),\n  partition: Int,\n  offset: Int,\n) -&gt; Builder(a)\n Add a commited offset to the topic subscriber builder.\nSynonyms:\nfranz/topic_subscriber.with_commited_offset\nfranz/topic_subscriber with_commited_offset","url":"franz/topic_subscriber.html#with_commited_offset"},{"doc":"franz/topic_subscriber","title":"with_config","content":"pub fn with_config(\n  builder: Builder(a),\n  consumer_config: ConsumerConfig,\n) -&gt; Builder(a)\n Add a consumer configuration to the topic subscriber builder.\nSynonyms:\nfranz/topic_subscriber.with_config\nfranz/topic_subscriber with_config","url":"franz/topic_subscriber.html#with_config"},{"doc":"franz/topic_subscriber","title":"franz/topic_subscriber","content":"","url":"franz/topic_subscriber.html"}]);